[jbpm-commits] JBoss JBPM SVN: r3623 - in jbpm4/trunk: modules/enterprise and 10 other directories.

do-not-reply at jboss.org do-not-reply at jboss.org
Fri Jan 9 01:18:25 EST 2009


Author: alex.guizar at jboss.com
Date: 2009-01-09 01:18:25 -0500 (Fri, 09 Jan 2009)
New Revision: 3623

Added:
   jbpm4/trunk/modules/enterprise/README
   jbpm4/trunk/modules/enterprise/scripts/assembly-test-dependencies.xml
   jbpm4/trunk/modules/enterprise/src/main/resources/jbpm.enterprise.wire.bindings.xml
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertCommentCmd.java
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemoveCommentCmd.java
   jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml
   jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties
   jbpm4/trunk/modules/enterprise/src/test/resources/jndi.properties
   jbpm4/trunk/modules/enterprise/src/test/resources/logging.properties
Removed:
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertPhraseCmd.java
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/Phrase.java
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemovePhraseCmd.java
   jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml
   jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties
   jbpm4/trunk/modules/enterprise/src/test/resources/org/
Modified:
   jbpm4/trunk/modules/enterprise/
   jbpm4/trunk/modules/enterprise/pom.xml
   jbpm4/trunk/modules/enterprise/scripts/antrun-test-jars.xml
   jbpm4/trunk/modules/enterprise/scripts/assembly-config.xml
   jbpm4/trunk/modules/enterprise/src/main/resources/META-INF/ejb-jar.xml
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/CommandExecutorTest.java
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/CommandReceiverTest.java
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/EjbTimerSessionTest.java
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/TimerTest.java
   jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/test/enterprise/IntegrationTestHelper.java
   jbpm4/trunk/modules/enterprise/src/test/resources/META-INF/application.xml
   jbpm4/trunk/modules/enterprise/src/test/resources/cactus.properties
   jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/AssignFileTypeDeployer.java
   jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/CheckProblemsDeployer.java
   jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/CheckProcessDeployer.java
   jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/SaveDeployer.java
   jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/wire/xml/WireParser.java
   jbpm4/trunk/pom.xml
Log:
include dependencies in test ear
remove spurious dependencies
parametrize jboss bind address
JBPM-1411


Property changes on: jbpm4/trunk/modules/enterprise
___________________________________________________________________
Name: svn:ignore
   - target

   + target
.settings


Added: jbpm4/trunk/modules/enterprise/README
===================================================================
--- jbpm4/trunk/modules/enterprise/README	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/README	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,15 @@
+Tests in the enterprise module are integration tests. The maven surefire plugin
+runs tests during the 'test' phase by default. This module is configured to
+skip test execution during the 'test' phase, allowing the build to reach the
+'package' phase and assemble the ejb jar.
+
+Enterprise tests are associated to the 'integration-test' phase that occurs
+after 'package' but before 'install'. In order to run properly, enterprise
+tests require a running JBoss application server. The address to which the
+server is bound must be specified in the Maven property 'jboss.bind.address',
+otherwise the tests will be skipped.
+
+mvn -Djboss.bind.address=127.0.0.1 integration-test
+
+Because several databases do not allow DDL in JTA transactions, the database
+schema has to be created prior to executing the tests for the first time.
\ No newline at end of file

Modified: jbpm4/trunk/modules/enterprise/pom.xml
===================================================================
--- jbpm4/trunk/modules/enterprise/pom.xml	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/pom.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -40,61 +40,48 @@
       <artifactId>jbpm-pvm</artifactId>
       <version>${version}</version>
     </dependency>
+
+    <!-- Provided Dependencies -->
     <dependency>
-      <groupId>log4j</groupId>
-      <artifactId>log4j</artifactId>
+      <groupId>org.apache.cactus</groupId>
+      <artifactId>cactus.core.framework.wrapper.javaEE.14</artifactId>
+      <scope>test</scope>
+      <exclusions>
+        <exclusion>
+          <artifactId>org.mortbay.jetty</artifactId>
+          <groupId>org.mortbay.jetty</groupId>
+        </exclusion>
+      </exclusions>
     </dependency>
     <dependency>
-      <groupId>juel</groupId>
-      <artifactId>juel</artifactId>
+      <groupId>org.apache.cactus</groupId>
+      <artifactId>cactus.integration.shared.api</artifactId>
+      <scope>test</scope>
+      <exclusions>
+        <exclusion>
+          <artifactId>org.mortbay.jetty</artifactId>
+          <groupId>org.mortbay.jetty</groupId>
+        </exclusion>
+      </exclusions>
     </dependency>
     <dependency>
-      <groupId>juel</groupId>
-      <artifactId>juel-engine</artifactId>
-    </dependency>
-    <dependency>
-      <groupId>juel</groupId>
-      <artifactId>juel-impl</artifactId>
-    </dependency>
-    <dependency>
-      <groupId>org.hibernate</groupId>
-      <artifactId>hibernate</artifactId>
-    </dependency>
-    <dependency>
-      <groupId>hsqldb</groupId>
-      <artifactId>hsqldb</artifactId>
-    </dependency>
-    <dependency>
-      <groupId>javax.servlet</groupId>
-      <artifactId>servlet-api</artifactId>
-    </dependency>
-    <dependency>
-      <groupId>junit</groupId>
-      <artifactId>junit</artifactId>
-      <!-- Not in scope test because org.jbpm.pvm.test.base package is in main source: see JBPM-1416 -->
-      <!-- <scope>test</scope> -->
-    </dependency>
-    <dependency>
-      <groupId>org.livetribe</groupId>
-      <artifactId>livetribe-jsr223</artifactId>
-    </dependency>
-    <dependency>
-      <groupId>org.springframework</groupId>
-      <artifactId>spring</artifactId>
-    </dependency>
-    <dependency>
-      <groupId>jboss</groupId>
-      <artifactId>jboss-j2ee</artifactId>
-    </dependency>
-    <dependency>
-      <groupId>cactus</groupId>
-      <artifactId>cactus</artifactId>
+      <groupId>org.jboss.client</groupId>
+      <artifactId>jbossall-client</artifactId>
       <scope>test</scope>
     </dependency>
+
+    <!-- Test Dependencies -->
   </dependencies>
 
   <!-- Plugins -->
   <build>
+  	<testResources>
+  		<testResource>
+  			<filtering>true</filtering>
+  			<directory>src/test/resources</directory>
+  		</testResource>
+  	</testResources>
+
     <plugins>
       <plugin>
         <artifactId>maven-compiler-plugin</artifactId>
@@ -104,39 +91,57 @@
       </plugin>
 
       <plugin>
-        <artifactId>maven-antrun-plugin</artifactId>
+        <artifactId>maven-assembly-plugin</artifactId>
         <executions>
           <execution>
-            <phase>pre-integration-test</phase>
+            <id>assembly-config</id>
+            <phase>package</phase>
             <goals>
-              <goal>run</goal>
+              <goal>single</goal>
             </goals>
             <configuration>
-              <tasks>
-                <property name="build.dir" value="${project.build.directory}" />
-                <property name="test.resources.dir" value="${build.dir}/test-classes" />
-                <property name="artifact.name" value="${project.build.finalName}.jar" />
-                <ant antfile="scripts/antrun-test-jars.xml" target="build-jars" />
-              </tasks>
+              <finalName>${project.build.finalName}</finalName>
+              <appendAssemblyId>true</appendAssemblyId>
+              <descriptors>
+                <descriptor>scripts/assembly-config.xml</descriptor>
+              </descriptors>
             </configuration>
           </execution>
+
+          <execution>
+            <id>assembly-test-dependencies</id>
+            <phase>generate-test-resources</phase>
+            <goals>
+              <goal>directory-single</goal>
+            </goals>
+            <configuration>
+              <finalName>test-dependencies</finalName>
+              <ignoreDirFormatExtensions>true</ignoreDirFormatExtensions>
+              <appendAssemblyId>false</appendAssemblyId>
+              <descriptors>
+                <descriptor>scripts/assembly-test-dependencies.xml</descriptor>
+              </descriptors>
+            </configuration>
+          </execution>
         </executions>
       </plugin>
 
       <plugin>
-        <artifactId>maven-surefire-plugin</artifactId>
-        <configuration>
-          <skip>true</skip>
-        </configuration>
+        <artifactId>maven-antrun-plugin</artifactId>
         <executions>
           <execution>
-            <id>integration-tests</id>
-            <phase>integration-test</phase>
+            <id>build-test-jars</id>
+            <phase>pre-integration-test</phase>
             <goals>
-              <goal>test</goal>
+              <goal>run</goal>
             </goals>
             <configuration>
-              <skip>false</skip>
+              <tasks>
+                <property name="build.dir" value="${project.build.directory}" />
+                <property name="test.resources.dir" value="${build.dir}/test-classes" />
+                <property name="build.finalName" value="${project.build.finalName}" />
+                <ant antfile="scripts/antrun-test-jars.xml" target="build-jars" />
+              </tasks>
             </configuration>
           </execution>
         </executions>
@@ -144,4 +149,56 @@
     </plugins>
   </build>
 
+  <profiles>
+    <profile>
+      <id>no-jboss-bind-address</id>
+      <activation>
+        <property>
+          <name>!jboss.bind.address</name>
+        </property>
+      </activation>
+      <build>
+        <plugins>
+          <plugin>
+            <artifactId>maven-surefire-plugin</artifactId>
+            <configuration>
+              <skipTests>true</skipTests>
+            </configuration>
+          </plugin>
+        </plugins>
+      </build>
+    </profile>
+
+    <profile>
+      <id>jboss-bind-address</id>
+      <activation>
+        <property>
+          <name>jboss.bind.address</name>
+        </property>
+      </activation>
+      <build>
+        <plugins>
+          <plugin>
+            <artifactId>maven-surefire-plugin</artifactId>
+            <configuration>
+              <skipTests>true</skipTests>
+            </configuration>
+            <executions>
+              <execution>
+                <id>integration-tests</id>
+                <phase>integration-test</phase>
+                <goals>
+                  <goal>test</goal>
+                </goals>
+                <configuration>
+                  <skipTests>false</skipTests>
+                </configuration>
+              </execution>
+            </executions>
+          </plugin>
+        </plugins>
+      </build>
+    </profile>
+  </profiles>
+
 </project>
\ No newline at end of file

Modified: jbpm4/trunk/modules/enterprise/scripts/antrun-test-jars.xml
===================================================================
--- jbpm4/trunk/modules/enterprise/scripts/antrun-test-jars.xml	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/scripts/antrun-test-jars.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -14,30 +14,42 @@
 
 	<target name="build-jars" description="Build the test modules.">
 
-		<war destfile="${build.dir}/jbpm-enterprise-test.war" webxml="${test.resources.dir}/WEB-INF/web.xml">
+	  <mkdir dir="${build.dir}/test-libs"/>
+
+		<war destfile="${build.dir}/test-libs/jbpm-enterprise-test.war" webxml="${test.resources.dir}/WEB-INF/web.xml">
 			<webinf dir="${test.resources.dir}/WEB-INF">
 				<exclude name="web.xml" />
 			</webinf>
+      <lib dir="${build.dir}/test-dependencies">
+        <include name="aspectjrt*.jar"/>
+        <include name="cactus*.jar"/>
+        <include name="junit*.jar"/>
+      </lib>
 		  <classes dir="${build.dir}/test-classes">
 		    <include name="org/jbpm/test/enterprise/*" />
 		    <include name="org/jbpm/enterprise/internal/ejb/*" />
 		  </classes>
 		</war>
 
-	  <jar destfile="${build.dir}/jbpm-enterprise-config.jar">
+	  <jar destfile="${build.dir}/test-libs/jbpm-enterprise-test.jar">
 	    <fileset dir="${build.dir}/test-classes">
 	      <include name="org/jbpm/enterprise/internal/custom/*" />
-	      <include name="environment.cfg.xml" />
-	      <include name="hibernate.properties" />
 	    </fileset>
 	  </jar>
 
-	  <ear destfile="${build.dir}/jbpm-enterprise-test.ear" appxml="${test.resources.dir}/META-INF/application.xml">
-			<fileset dir="${build.dir}">
-				<include name="${artifact.name}" />
-				<include name="jbpm-enterprise-test.war" />
-			  <include name="jbpm-enterprise-config.jar" />
-			</fileset>
+	  <ear destfile="${build.dir}/test-libs/jbpm-enterprise-test.ear" appxml="${test.resources.dir}/META-INF/application.xml">
+	    <!-- artifacts -->
+			<fileset dir="${build.dir}" includes="${build.finalName}.jar" />
+	    <zipfileset dir="${build.dir}" includes="${build.finalName}-config.jar" prefix="lib" />
+	    <!-- test modules -->
+	    <fileset dir="${build.dir}/test-libs" includes="jbpm-enterprise-test.war" />
+	    <zipfileset dir="${build.dir}/test-libs" includes="jbpm-enterprise-test.jar" prefix="lib" />
+	    <!-- dependencies -->
+	    <zipfileset dir="${build.dir}/test-dependencies" prefix="lib">
+	      <include name="jbpm-api*.jar" />
+	      <include name="jbpm-pvm*.jar" />
+	      <include name="jbpm-log*.jar" />
+	    </zipfileset>
 		</ear>
 
 		<!-- Please add alphabetically -->

Modified: jbpm4/trunk/modules/enterprise/scripts/assembly-config.xml
===================================================================
--- jbpm4/trunk/modules/enterprise/scripts/assembly-config.xml	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/scripts/assembly-config.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1,26 +1,21 @@
 <assembly xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/assembly-1.1.0-SNAPSHOT.xsd">
+
   <id>config</id>
   <formats>
     <format>jar</format>
   </formats>
   <includeBaseDirectory>false</includeBaseDirectory>
+
   <fileSets>
     <fileSet>
-      <directory>src/main/resources</directory>
-      <outputDirectory>/</outputDirectory>
-      <includes>
-        <include>hibernate.cfg.xml</include>
-        <include>jbpm.cfg.xml</include>
-        <include>jbpm.mail.templates.xml</include>
-      </includes>
-    </fileSet>
-    <fileSet>
       <directory>src/test/resources</directory>
       <outputDirectory>/</outputDirectory>
       <includes>
-        <include>log4j.xml</include>
+        <include>environment.cfg.xml</include>
+        <include>hibernate.properties</include>
       </includes>
     </fileSet>
   </fileSets>
+
 </assembly>
\ No newline at end of file

Added: jbpm4/trunk/modules/enterprise/scripts/assembly-test-dependencies.xml
===================================================================
--- jbpm4/trunk/modules/enterprise/scripts/assembly-test-dependencies.xml	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/scripts/assembly-test-dependencies.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,31 @@
+<assembly xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+  xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/assembly-1.1.0-SNAPSHOT.xsd">
+
+  <id>test-dependencies</id>
+  <formats>
+    <format>dir</format>
+  </formats>
+  <includeBaseDirectory>false</includeBaseDirectory>
+
+  <!-- Dependency Sets -->
+  <dependencySets>
+    <dependencySet>
+      <outputDirectory>/</outputDirectory>
+      <useStrictFiltering>true</useStrictFiltering>
+      <includes>
+        <include>aspectj:aspectjrt:jar</include>
+        <include>org.apache.cactus:cactus.integration.shared.api</include>
+        <include>org.apache.cactus:cactus.core.framework.wrapper.javaEE.14</include>
+        <include>org.apache.cactus:cactus.core.framework.javaEE.13-14</include>
+        <include>org.apache.cactus:cactus.core.framework.javaEE.12-13-14</include>
+        <include>junit:junit</include>
+        <include>org.jbpm.jbpm4:jbpm-api</include>
+        <include>org.jbpm.jbpm4:jbpm-pvm</include>
+        <include>org.jbpm.jbpm4:jbpm-log</include>
+      </includes>
+      <unpack>false</unpack>
+      <scope>test</scope>
+    </dependencySet>
+  </dependencySets>
+
+</assembly>

Modified: jbpm4/trunk/modules/enterprise/src/main/resources/META-INF/ejb-jar.xml
===================================================================
--- jbpm4/trunk/modules/enterprise/src/main/resources/META-INF/ejb-jar.xml	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/main/resources/META-INF/ejb-jar.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -14,18 +14,18 @@
       <description>JBoss jBPM Command Executor SLSB</description>
       <display-name>JBoss jBPM Command Executor SLSB</display-name>
       <ejb-name>CommandExecutor</ejb-name>
-      <home>org.jbpm.pvm.internal.ejb.RemoteCommandExecutorHome</home>
-      <remote>org.jbpm.pvm.internal.ejb.RemoteCommandExecutor</remote>
-      <local-home>org.jbpm.pvm.internal.ejb.LocalCommandExecutorHome</local-home>
-      <local>org.jbpm.pvm.internal.ejb.LocalCommandExecutor</local>
-      <ejb-class>org.jbpm.pvm.internal.ejb.CommandExecutorSLSB</ejb-class>
+      <home>org.jbpm.enterprise.internal.ejb.RemoteCommandExecutorHome</home>
+      <remote>org.jbpm.enterprise.internal.ejb.RemoteCommandExecutor</remote>
+      <local-home>org.jbpm.enterprise.internal.ejb.LocalCommandExecutorHome</local-home>
+      <local>org.jbpm.enterprise.internal.ejb.LocalCommandExecutor</local>
+      <ejb-class>org.jbpm.enterprise.internal.ejb.CommandExecutorSLSB</ejb-class>
       <session-type>Stateless</session-type>
       <transaction-type>Container</transaction-type>
       <ejb-local-ref>
         <ejb-ref-name>ejb/LocalTimer</ejb-ref-name>
         <ejb-ref-type>Entity</ejb-ref-type>
-        <local-home>org.jbpm.pvm.internal.ejb.LocalTimerHome</local-home>
-        <local>org.jbpm.pvm.internal.ejb.LocalTimer</local>
+        <local-home>org.jbpm.enterprise.internal.ejb.LocalTimerHome</local-home>
+        <local>org.jbpm.enterprise.internal.ejb.LocalTimer</local>
         <ejb-link>Timer</ejb-link>
       </ejb-local-ref>
     </session>
@@ -33,14 +33,14 @@
     <message-driven>
       <description>JBoss jBPM Command Receiver MDB</description>
       <ejb-name>CommandReceiver</ejb-name>
-      <ejb-class>org.jbpm.pvm.internal.ejb.CommandReceiverMDB</ejb-class>
+      <ejb-class>org.jbpm.enterprise.internal.ejb.CommandReceiverMDB</ejb-class>
       <transaction-type>Container</transaction-type>
       <message-destination-type>javax.jms.Queue</message-destination-type>
       <ejb-local-ref>
         <ejb-ref-name>ejb/LocalCommandExecutor</ejb-ref-name>
         <ejb-ref-type>Session</ejb-ref-type>
-        <local-home>org.jbpm.pvm.internal.ejb.LocalCommandExecutorHome</local-home>
-        <local>org.jbpm.pvm.internal.ejb.LocalCommandExecutor</local>
+        <local-home>org.jbpm.enterprise.internal.ejb.LocalCommandExecutorHome</local-home>
+        <local>org.jbpm.enterprise.internal.ejb.LocalCommandExecutor</local>
         <ejb-link>CommandExecutor</ejb-link>
       </ejb-local-ref>
       <resource-ref>
@@ -59,9 +59,9 @@
     <entity>
       <display-name>JBoss jBPM Timer EB</display-name>
       <ejb-name>Timer</ejb-name>
-      <local-home>org.jbpm.pvm.internal.ejb.LocalTimerHome</local-home>
-      <local>org.jbpm.pvm.internal.ejb.LocalTimer</local>
-      <ejb-class>org.jbpm.pvm.internal.ejb.TimerEB</ejb-class>
+      <local-home>org.jbpm.enterprise.internal.ejb.LocalTimerHome</local-home>
+      <local>org.jbpm.enterprise.internal.ejb.LocalTimer</local>
+      <ejb-class>org.jbpm.enterprise.internal.ejb.TimerEB</ejb-class>
       <persistence-type>Container</persistence-type>
       <prim-key-class>java.lang.Long</prim-key-class>
       <reentrant>false</reentrant>
@@ -82,8 +82,8 @@
       <ejb-local-ref>
         <ejb-ref-name>ejb/LocalCommandExecutor</ejb-ref-name>
         <ejb-ref-type>Session</ejb-ref-type>
-        <local-home>org.jbpm.pvm.internal.ejb.LocalCommandExecutorHome</local-home>
-        <local>org.jbpm.pvm.internal.ejb.LocalCommandExecutor</local>
+        <local-home>org.jbpm.enterprise.internal.ejb.LocalCommandExecutorHome</local-home>
+        <local>org.jbpm.enterprise.internal.ejb.LocalCommandExecutor</local>
         <ejb-link>CommandExecutor</ejb-link>
       </ejb-local-ref>
     </entity>

Added: jbpm4/trunk/modules/enterprise/src/main/resources/jbpm.enterprise.wire.bindings.xml
===================================================================
--- jbpm4/trunk/modules/enterprise/src/main/resources/jbpm.enterprise.wire.bindings.xml	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/src/main/resources/jbpm.enterprise.wire.bindings.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,6 @@
+<wire-bindings>
+
+  <binding class="org.jbpm.enterprise.internal.wire.binding.EjbTimerSessionBinding" />
+  <binding class="org.jbpm.enterprise.internal.wire.binding.EjbLocalCommandServiceBinding" />
+
+</wire-bindings>

Copied: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertCommentCmd.java (from rev 3612, jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertPhraseCmd.java)
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertCommentCmd.java	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertCommentCmd.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,63 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jbpm.enterprise.internal.custom;
+
+import java.sql.SQLException;
+
+import org.jbpm.cmd.Command;
+import org.jbpm.env.Environment;
+import org.jbpm.pvm.internal.model.CommentImpl;
+import org.jbpm.session.DbSession;
+
+/**
+ * @author Alejandro Guizar
+ */
+public class InsertCommentCmd implements Command<Void> {
+
+  private final String message;
+  private final boolean fail;
+
+  private static final long serialVersionUID = 1L;
+
+  public InsertCommentCmd(String message) {
+    this(message, false);
+  }
+
+  public InsertCommentCmd(String message, boolean fail) {
+    this.message = message;
+    this.fail = fail;
+  }
+
+  public Void execute(Environment environment) throws Exception {
+    CommentImpl comment = new CommentImpl();
+    comment.setMessage(message);
+    environment.get(DbSession.class).save(comment);
+    if (fail)
+      throw new SQLException("simulated failure");
+    return null;
+  }
+
+  @Override
+  public String toString() {
+    return InsertCommentCmd.class.getSimpleName() + '(' + message + ')';
+  }
+}
\ No newline at end of file


Property changes on: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertCommentCmd.java
___________________________________________________________________
Name: svn:keywords
   + Id Revision
Name: svn:mergeinfo
   + 
Name: svn:eol-style
   + LF

Deleted: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertPhraseCmd.java
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertPhraseCmd.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/InsertPhraseCmd.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1,62 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jbpm.enterprise.internal.custom;
-
-import java.sql.SQLException;
-
-import org.jbpm.cmd.Command;
-import org.jbpm.env.Environment;
-import org.jbpm.session.DbSession;
-
-/**
- * @author Alejandro Guizar
- */
-public class InsertPhraseCmd implements Command<Void> {
-
-  private final String text;
-  private final boolean fail;
-
-  private static final long serialVersionUID = 1L;
-
-  public InsertPhraseCmd(String text) {
-    this(text, false);
-  }
-
-  public InsertPhraseCmd(String text, boolean fail) {
-    this.text = text;
-    this.fail = fail;
-  }
-
-  public Void execute(Environment environment) throws Exception {
-    Phrase phrase = new Phrase();
-    phrase.setText(text);
-    environment.get(DbSession.class).save(phrase);
-    if (fail)
-      throw new SQLException("simulated failure");
-    return null;
-  }
-
-  @Override
-  public String toString() {
-    return InsertPhraseCmd.class.getSimpleName() + '(' + text + ')';
-  }
-}
\ No newline at end of file

Deleted: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/Phrase.java
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/Phrase.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/Phrase.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1,43 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jbpm.enterprise.internal.custom;
-
-/**
- * @author Alejandro Guizar
- */
-public class Phrase {
-
-  private Long id;
-  private String text;
-
-  public Long getId() {
-    return id;
-  }
-
-  public String getText() {
-    return text;
-  }
-
-  public void setText(String text) {
-    this.text = text;
-  }
-}

Copied: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemoveCommentCmd.java (from rev 3612, jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemovePhraseCmd.java)
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemoveCommentCmd.java	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemoveCommentCmd.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,62 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jbpm.enterprise.internal.custom;
+
+import java.util.List;
+
+import org.hibernate.Session;
+import org.hibernate.criterion.Restrictions;
+
+import org.jbpm.cmd.Command;
+import org.jbpm.env.Environment;
+import org.jbpm.pvm.internal.model.CommentImpl;
+
+/**
+ * @author Alejandro Guizar
+ */
+public class RemoveCommentCmd implements Command<Boolean> {
+
+  private final String message;
+
+  private static final long serialVersionUID = 1L;
+
+  public RemoveCommentCmd(String message) {
+    this.message = message;
+  }
+
+  public Boolean execute(Environment environment) throws Exception {
+    Session session = environment.get(Session.class);
+    List<?> comments = session.createCriteria(CommentImpl.class)
+        .add(Restrictions.eq("message", message))
+        .setMaxResults(1)
+        .list();
+    if (comments.isEmpty())
+      return false;
+    CommentImpl phrase = (CommentImpl) comments.get(0);
+    session.delete(phrase);
+    return true;
+  }
+
+  public String toString() {
+    return RemoveCommentCmd.class.getSimpleName() + '(' + message + ')';
+  }
+}
\ No newline at end of file


Property changes on: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemoveCommentCmd.java
___________________________________________________________________
Name: svn:keywords
   + Id Revision
Name: svn:mergeinfo
   + 
Name: svn:eol-style
   + LF

Deleted: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemovePhraseCmd.java
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemovePhraseCmd.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/custom/RemovePhraseCmd.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1,61 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jbpm.enterprise.internal.custom;
-
-import java.util.List;
-
-import org.hibernate.Session;
-import org.hibernate.criterion.Restrictions;
-
-import org.jbpm.cmd.Command;
-import org.jbpm.env.Environment;
-
-/**
- * @author Alejandro Guizar
- */
-public class RemovePhraseCmd implements Command<Boolean> {
-
-  private final String text;
-
-  private static final long serialVersionUID = 1L;
-
-  public RemovePhraseCmd(String text) {
-    this.text = text;
-  }
-
-  public Boolean execute(Environment environment) throws Exception {
-    Session session = environment.get(Session.class);
-    List<?> phrases = session.createCriteria(Phrase.class)
-        .add(Restrictions.eq("text", text))
-        .setMaxResults(1)
-        .list();
-    if (phrases.isEmpty())
-      return false;
-    Phrase phrase = (Phrase) phrases.get(0);
-    session.delete(phrase);
-    return true;
-  }
-
-  public String toString() {
-    return RemovePhraseCmd.class.getSimpleName() + '(' + text + ')';
-  }
-}
\ No newline at end of file

Modified: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/CommandExecutorTest.java
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/EjbTimerSessionTest.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/EjbTimerSessionTest.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -22,6 +22,7 @@
 package org.jbpm.enterprise.internal.ejb;
 
 import java.util.Date;
+import java.util.List;
 
 import javax.ejb.CreateException;
 import javax.naming.Context;
@@ -30,13 +31,11 @@
 import junit.framework.Test;
 
 import org.apache.cactus.ServletTestCase;
+import org.jbpm.ProcessDefinition;
+import org.jbpm.client.ClientProcessDefinition;
 import org.jbpm.cmd.Command;
 import org.jbpm.enterprise.internal.custom.HappyActivity;
-import org.jbpm.enterprise.internal.ejb.EjbTimerSession;
-import org.jbpm.enterprise.internal.ejb.LocalCommandExecutor;
-import org.jbpm.enterprise.internal.ejb.LocalCommandExecutorHome;
 import org.jbpm.env.Environment;
-import org.jbpm.model.OpenProcessDefinition;
 import org.jbpm.pvm.internal.cmd.DeployCmd;
 import org.jbpm.pvm.internal.cmd.StartExecutionCmd;
 import org.jbpm.pvm.internal.job.TimerImpl;
@@ -48,8 +47,8 @@
 import org.jbpm.test.enterprise.IntegrationTestSetup;
 
 /**
- * Server-side test for the enterprise {@linkplain EjbTimerSession
- * timerImpl session}.
+ * Server-side test for the enterprise {@linkplain EjbTimerSession timer
+ * session}.
  * 
  * @author Alejandro Guizar
  */
@@ -58,6 +57,8 @@
   private LocalCommandExecutor commandExecutor;
   private static LocalCommandExecutorHome commandExecutorHome;
 
+  private String processDefinitionId;
+
   private static final int TIMEOUT = 2000;
 
   public static Test suite() {
@@ -72,18 +73,22 @@
       try {
         commandExecutorHome = (LocalCommandExecutorHome) initialContext
             .lookup("java:comp/env/ejb/LocalCommandExecutor");
-      } finally {
+      }
+      finally {
         initialContext.close();
       }
     }
     // create local bean
     commandExecutor = commandExecutorHome.create();
     // deploy process
-    OpenProcessDefinition processDefinition = ProcessFactory.build(getName())
-        .timer(TIMEOUT + " milliseconds", null).event("timeout").listener(
-            new ObjectDescriptor(HappyActivity.class)).done();
-    commandExecutor
+    ClientProcessDefinition processDefinition = ProcessFactory.build(getName())
+        .node().initial().timer(TIMEOUT + " milliseconds", null).event(
+            "timeout").listener(new ObjectDescriptor(HappyActivity.class))
+        .done();
+    List<ProcessDefinition> processDefinitions = commandExecutor
         .execute(new DeployCmd(new DeploymentImpl(processDefinition)));
+    assertEquals(1, processDefinitions.size());
+    processDefinitionId = processDefinitions.get(0).getId();
   }
 
   protected void tearDown() throws Exception {
@@ -91,19 +96,19 @@
   }
 
   /**
-   * This scenario schedules a non-repeating timerImpl whose referenced activity
+   * This scenario schedules a non-repeating timer whose referenced activity
    * completes with no incident. <h3>Preconditions</h3> The activity has not
    * executed. <h3>Behavior</h3> The {@link ScheduleTimerCmd} command activates
-   * a timerImpl. After that, the test waits for the activity to execute. Upon
+   * a timer. After that, the test waits for the activity to execute. Upon
    * timeout, the {@linkplain HappyActivity activity} notifies the test of its
    * execution. <h3>Postconditions</h3> The activity executes on or after the
-   * timerImpl's due date.
+   * timer's due date.
    */
   public void testSchedule() throws CreateException {
     // start an execution
     Date dueDate = new Date(System.currentTimeMillis() + TIMEOUT);
-    commandExecutor
-        .execute(new StartExecutionCmd("timers included", null, null));
+    commandExecutor.execute(new StartExecutionCmd(processDefinitionId, null,
+        null));
 
     // wait for activity to execute
     Date executionDate = HappyActivity.waitFor();
@@ -111,17 +116,17 @@
   }
 
   /**
-   * This scenario schedules a non-repeating timerImpl and immediately cancels
-   * it. <h3>Preconditions</h3> The activity has not executed. <h3>Behavior</h3>
-   * The {@link ScheduleTimerCmd} command activates a timerImpl, which is
-   * immediately disabled by the {@link CancelTimerCmd} command. After that, the
-   * test waits past the timerImpl's due date. <h3>Postconditions</h3> The
-   * activity does not execute, ever.
+   * This scenario schedules a non-repeating timer and immediately cancels it.
+   * <h3>Preconditions</h3> The activity has not executed. <h3>Behavior</h3> The
+   * {@link ScheduleTimerCmd} command activates a timer, which is immediately
+   * disabled by the {@link CancelTimerCmd} command. After that, the test waits
+   * past the timer's due date. <h3>Postconditions</h3> The activity does not
+   * execute, ever.
    */
   public void testCancel() throws CreateException {
     // start an execution
-    commandExecutor
-        .execute(new StartExecutionCmd("timers included", null, null));
+    commandExecutor.execute(new StartExecutionCmd(processDefinitionId, null,
+        null));
 
     Date executionDate = HappyActivity.waitFor(2 * TIMEOUT);
     assertNull(executionDate);
@@ -155,9 +160,9 @@
     }
 
     public Void execute(Environment environment) throws Exception {
-      TimerImpl timerImpl = environment.get(DbSession.class).get(
-          TimerImpl.class, timerDbid);
-      environment.get(TimerSession.class).cancel(timerImpl);
+      TimerImpl timer = environment.get(DbSession.class).get(TimerImpl.class,
+          timerDbid);
+      environment.get(TimerSession.class).cancel(timer);
       return null;
     }
   }

Modified: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/TimerTest.java
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/TimerTest.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/TimerTest.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -83,19 +83,21 @@
     if (commandExecutorHome == null) {
       InitialContext initialContext = new InitialContext();
       try {
-        commandExecutorHome = (LocalCommandExecutorHome) initialContext.lookup("java:comp/env/ejb/LocalCommandExecutor");
-        timerHome = (LocalTimerHome) initialContext.lookup("java:comp/env/ejb/LocalTimer");
-      } finally {
+        commandExecutorHome = (LocalCommandExecutorHome) initialContext
+            .lookup("java:comp/env/ejb/LocalCommandExecutor");
+        timerHome = (LocalTimerHome) initialContext
+            .lookup("java:comp/env/ejb/LocalTimer");
+      }
+      finally {
         initialContext.close();
       }
     }
     // create local bean
     commandExecutor = commandExecutorHome.create();
     // define process
-    processDefinition = ProcessFactory.build(getName())
-      .event("timeout")
-        .listener(activityDescriptor)
-      .done();
+    processDefinition = ProcessFactory.build(getName()).node().initial().timer(
+        TIMEOUT + " milliseconds", null).event("timeout").listener(
+        activityDescriptor).done();
   }
 
   protected void tearDown() throws Exception {
@@ -104,23 +106,21 @@
 
   /**
    * This scenario tests a non-repeating timerImpl whose referenced activity
-   * completes with no incident.
-   * <h3>Preconditions</h3>
-   * The activity has not executed.
-   * <h3>Behavior</h3>
-   * The {@link CreateTimerCmd} command subscribes a timerImpl bean to the EJB timerImpl
-   * service. After that, the test waits for the activity to execute. Upon
-   * timeout, the {@linkplain HappyActivity activity} notifies the test of its
-   * execution.
-   * <h3>Postconditions</h3>
-   * The activity executes on or after the timerImpl's due date.
+   * completes with no incident. <h3>Preconditions</h3> The activity has not
+   * executed. <h3>Behavior</h3> The {@link CreateTimerCmd} command subscribes a
+   * timerImpl bean to the EJB timerImpl service. After that, the test waits for
+   * the activity to execute. Upon timeout, the {@linkplain HappyActivity
+   * activity} notifies the test of its execution. <h3>Postconditions</h3> The
+   * activity executes on or after the timerImpl's due date.
    */
   public void testHappyTimer() throws CreateException {
     activityDescriptor.setClassName(HappyActivity.class.getName());
-    commandExecutor.execute(new DeployCmd(new DeploymentImpl(processDefinition)));
+    commandExecutor
+        .execute(new DeployCmd(new DeploymentImpl(processDefinition)));
 
-    ExecutionImpl execution = (ExecutionImpl) commandExecutor.execute(new StartExecutionCmd(processDefinition.getName(), null, null));
-    
+    ExecutionImpl execution = (ExecutionImpl) commandExecutor
+        .execute(new StartExecutionCmd(processDefinition.getId(), null, null));
+
     Date dueDate = new Date(System.currentTimeMillis() + TIMEOUT);
     TimerImpl timerImpl = new TimerImpl();
     timerImpl.setEventName("timeout");
@@ -133,25 +133,24 @@
   }
 
   /**
-   * This scenario tests a non-repeating timerImpl whose referenced activity throws
-   * a checked exception.
-   * <h3>Preconditions</h3>
-   * The activity has not executed.
-   * <h3>Behavior</h3>
-   * The {@link CreateTimerCmd} command subscribes a timerImpl bean to the EJB timerImpl
-   * service. After that, the test waits for the activity to execute. Upon
-   * timeout, the {@linkplain NoisyActivity activity} notifies the test of its
-   * execution, sets a variable and throws a checked exception.
-   * <h3>Postconditions</h3>
-   * The activity executes on or after the timerImpl's due date. The EJB timerImpl
-   * service rolls back the managed transaction. The variable is unset.
+   * This scenario tests a non-repeating timerImpl whose referenced activity
+   * throws a checked exception. <h3>Preconditions</h3> The activity has not
+   * executed. <h3>Behavior</h3> The {@link CreateTimerCmd} command subscribes a
+   * timerImpl bean to the EJB timerImpl service. After that, the test waits for
+   * the activity to execute. Upon timeout, the {@linkplain NoisyActivity
+   * activity} notifies the test of its execution, sets a variable and throws a
+   * checked exception. <h3>Postconditions</h3> The activity executes on or
+   * after the timerImpl's due date. The EJB timerImpl service rolls back the
+   * managed transaction. The variable is unset.
    */
   public void testNoisyTimer() throws CreateException {
     activityDescriptor.setClassName(NoisyActivity.class.getName());
-    commandExecutor.execute(new DeployCmd(new DeploymentImpl(processDefinition)));
+    commandExecutor
+        .execute(new DeployCmd(new DeploymentImpl(processDefinition)));
 
-    ExecutionImpl execution = (ExecutionImpl) commandExecutor.execute(new StartExecutionCmd(processDefinition.getName(), null, null));
-    
+    ExecutionImpl execution = (ExecutionImpl) commandExecutor
+        .execute(new StartExecutionCmd(processDefinition.getId(), null, null));
+
     Date dueDate = new Date(System.currentTimeMillis() + TIMEOUT);
     TimerImpl timerImpl = new TimerImpl();
     timerImpl.setEventName("timeout");
@@ -164,31 +163,30 @@
 
     Set<String> variableNames = new HashSet<String>();
     variableNames.add("executionDate");
-    Object variableValue = commandExecutor.execute(new GetVariablesCmd(execution.getId(), variableNames));
+    Object variableValue = commandExecutor.execute(new GetVariablesCmd(
+        execution.getId(), variableNames));
     assertNull(variableValue);
   }
 
   /**
-   * This scenario tests a repeating timerImpl whose referenced activity completes
-   * with no incident.
-   * <h3>Preconditions</h3>
-   * The activity has not executed.
-   * <h3>Behavior</h3>
-   * The {@link CreateTimerCmd} command subscribes a timerImpl bean to the EJB timerImpl
-   * service. After that, the test waits for the first execution of the
-   * activity, and then for the subsequent <em>n</em> executions of the
-   * activity. Upon each timeout, the {@linkplain HappyActivity activity}
-   * notifies the test of its execution.
-   * <h3>Postconditions</h3>
-   * The first execution of the activity occurs on or after the timerImpl's due
-   * date. The subsequent <em>n</em> executions of the activity occur on or
-   * after the timerImpl's repeat interval.
+   * This scenario tests a repeating timerImpl whose referenced activity
+   * completes with no incident. <h3>Preconditions</h3> The activity has not
+   * executed. <h3>Behavior</h3> The {@link CreateTimerCmd} command subscribes a
+   * timerImpl bean to the EJB timerImpl service. After that, the test waits for
+   * the first execution of the activity, and then for the subsequent <em>n</em>
+   * executions of the activity. Upon each timeout, the
+   * {@linkplain HappyActivity activity} notifies the test of its execution. <h3>
+   * Postconditions</h3> The first execution of the activity occurs on or after
+   * the timerImpl's due date. The subsequent <em>n</em> executions of the
+   * activity occur on or after the timerImpl's repeat interval.
    */
   public void testCyclicTimer() throws CreateException {
     activityDescriptor.setClassName(HappyActivity.class.getName());
-    commandExecutor.execute(new DeployCmd(new DeploymentImpl(processDefinition)));
+    commandExecutor
+        .execute(new DeployCmd(new DeploymentImpl(processDefinition)));
 
-    ExecutionImpl execution = (ExecutionImpl) commandExecutor.execute(new StartExecutionCmd(processDefinition.getName(), null, null));
+    ExecutionImpl execution = (ExecutionImpl) commandExecutor
+        .execute(new StartExecutionCmd(processDefinition.getId(), null, null));
 
     Date dueDate = new Date(System.currentTimeMillis() + TIMEOUT);
     TimerImpl timerImpl = new TimerImpl();
@@ -208,7 +206,8 @@
         executionTime = HappyActivity.waitFor();
         assertTrue(dueDate.compareTo(executionTime) <= 0);
       }
-    } finally {
+    }
+    finally {
       commandExecutor.execute(new CancelTimerCmd(timerImpl.getDbid()));
     }
   }

Modified: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/test/enterprise/IntegrationTestHelper.java
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/test/enterprise/IntegrationTestHelper.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/test/enterprise/IntegrationTestHelper.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -153,10 +153,10 @@
   }
 
   public String getTestResourcesDir() {
-    if (testResourcesDir == null)
+    if (testResourcesDir == null) {
       testResourcesDir = System.getProperty(SYSPROP_TEST_RESOURCES_DIRECTORY,
           "target/test-classes");
-
+    }
     return testResourcesDir;
   }
 
@@ -175,17 +175,17 @@
     if (file.exists())
       return file;
 
-    String notSet = (getTestArchiveDir() == null ? " System property '"
-        + SYSPROP_TEST_ARCHIVE_DIRECTORY + "' not set." : "");
+    String notSet = getTestArchiveDir() == null ? " System property '"
+        + SYSPROP_TEST_ARCHIVE_DIRECTORY + "' not set." : "";
     throw new IllegalArgumentException("Cannot obtain '" + getTestArchiveDir()
         + "/" + archive + "'." + notSet);
   }
 
   public String getTestArchiveDir() {
-    if (testArchiveDir == null)
+    if (testArchiveDir == null) {
       testArchiveDir = System.getProperty(SYSPROP_TEST_ARCHIVE_DIRECTORY,
           "target/test-libs");
-
+    }
     return testArchiveDir;
   }
 }

Modified: jbpm4/trunk/modules/enterprise/src/test/resources/META-INF/application.xml
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/resources/META-INF/application.xml	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/resources/META-INF/application.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<application version="1.4"
-  xsi:schemaLocation="http://java.sun.com/xml/ns/j2ee http://java.sun.com/xml/ns/j2ee/application_1_4.xsd"
-  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="http://java.sun.com/xml/ns/j2ee">
+<application version="5"
+  xsi:schemaLocation="http://java.sun.com/xml/ns/javaee http://java.sun.com/xml/ns/javaee/application_5.xsd"
+  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="http://java.sun.com/xml/ns/javaee">
 
   <display-name>JBoss jBPM enterprise beans</display-name>
 
@@ -16,9 +16,6 @@
       <context-root>/jbpm-enterprise-test</context-root>
     </web>
   </module>
+  <library-directory>lib</library-directory>
 
-  <module>
-    <java>jbpm-enterprise-test.jar</java>
-  </module>
-
 </application>

Modified: jbpm4/trunk/modules/enterprise/src/test/resources/cactus.properties
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/resources/cactus.properties	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/resources/cactus.properties	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1 +1 @@
-cactus.contextURL = http://localhost:8080/pvm-enterprise-test
\ No newline at end of file
+cactus.contextURL =http\://${jboss.bind.address}\:8080/jbpm-enterprise-test
\ No newline at end of file

Deleted: jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1,35 +0,0 @@
-<jbpm-configuration>
-
-  <process-engine>
-
-    <hibernate-configuration>
-      <properties resource="hibernate.properties" />
-      <mapping resource="jbpm.pvm.typedefs.hbm.xml" />
-      <mapping resource="jbpm.pvm.wire.hbm.xml" />
-      <mapping resource="jbpm.pvm.definition.hbm.xml" />
-      <mapping resource="jbpm.pvm.execution.hbm.xml" />
-      <mapping resource="jbpm.pvm.variable.hbm.xml" />
-      <mapping resource="jbpm.pvm.job.hbm.xml" />
-      <mapping resource="org/jbpm/enterprise/internal/custom/mappings.hbm.xml" />
-      <cache-configuration resource="jbpm.pvm.cache.xml"
-        usage="nonstrict-read-write" />
-    </hibernate-configuration>
-
-    <hibernate-session-factory />
-
-    <variable-types resource="jbpm.pvm.types.xml" />
-
-    <ejb-local-command-service />
-
-  </process-engine>
-
-  <environment>
-
-    <hibernate-session />
-    <pvm-db-session />
-
-    <ejb-timer-session />
-
-  </environment>
-
-</jbpm-configuration>

Copied: jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml (from rev 3612, jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml)
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,43 @@
+<jbpm-configuration>
+
+  <process-engine>
+
+    <deployer-manager>
+      <assign-file-type>
+        <file extension=".jpdl.xml" type="jpdl" />
+      </assign-file-type>
+      <check-process />
+      <check-problems />
+      <save />
+    </deployer-manager>
+    
+    <process-service />
+    <execution-service />
+    <management-service />
+    <ejb-local-command-service />
+
+    <hibernate-configuration>
+      <properties resource="hibernate.properties" />
+      <mapping resource="jbpm.pvm.typedefs.hbm.xml" />
+      <mapping resource="jbpm.pvm.wire.hbm.xml" />
+      <mapping resource="jbpm.pvm.definition.hbm.xml" />
+      <mapping resource="jbpm.pvm.execution.hbm.xml" />
+      <mapping resource="jbpm.pvm.variable.hbm.xml" />
+      <mapping resource="jbpm.pvm.job.hbm.xml" />
+      <cache-configuration resource="jbpm.pvm.cache.xml"
+        usage="nonstrict-read-write" />
+    </hibernate-configuration>
+    <hibernate-session-factory />
+    <id-generator />
+
+    <variable-types resource="jbpm.pvm.types.xml" />
+
+  </process-engine>
+
+  <environment>
+    <hibernate-session />
+    <pvm-db-session />
+    <ejb-timer-session />
+  </environment>
+
+</jbpm-configuration>


Property changes on: jbpm4/trunk/modules/enterprise/src/test/resources/environment.cfg.xml
___________________________________________________________________
Name: svn:mergeinfo
   + 

Deleted: jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1,7 +0,0 @@
-hibernate.dialect                      org.hibernate.dialect.HSQLDialect
-hibernate.connection.datasource        java:JbpmDS
-hibernate.hbm2ddl.auto                 create-drop
-hibernate.cache.use_second_level_cache true
-hibernate.cache.provider_class         org.hibernate.cache.HashtableCacheProvider
-hibernate.format_sql                   true
-hibernate.use_sql_comments             true

Copied: jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties (from rev 3612, jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties)
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,4 @@
+hibernate.connection.datasource        java:DefaultDS
+hibernate.cache.provider_class         org.hibernate.cache.HashtableCacheProvider
+hibernate.format_sql                   true
+hibernate.use_sql_comments             true


Property changes on: jbpm4/trunk/modules/enterprise/src/test/resources/hibernate.properties
___________________________________________________________________
Name: svn:mergeinfo
   + 

Added: jbpm4/trunk/modules/enterprise/src/test/resources/jndi.properties
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/resources/jndi.properties	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/src/test/resources/jndi.properties	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,3 @@
+java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
+java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces
+java.naming.provider.url=jnp\://${jboss.bind.address}\:1099

Added: jbpm4/trunk/modules/enterprise/src/test/resources/logging.properties
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/resources/logging.properties	                        (rev 0)
+++ jbpm4/trunk/modules/enterprise/src/test/resources/logging.properties	2009-01-09 06:18:25 UTC (rev 3623)
@@ -0,0 +1,28 @@
+handlers= java.util.logging.ConsoleHandler
+# to add the error triggered file handler
+# handlers= java.util.logging.ConsoleHandler org.jbpm.util.ErrorTriggeredFileHandler
+
+redirect.commons.logging = enabled
+
+java.util.logging.ConsoleHandler.level = FINEST
+java.util.logging.ConsoleHandler.formatter = org.jbpm.log.LogFormatter
+
+# org.jbpm.util.ErrorTriggeredFileHandler.size = 500
+# org.jbpm.util.ErrorTriggeredFileHandler.push = OFF
+# org.jbpm.util.ErrorTriggeredFileHandler.pattern = %h/jbpm%u.log
+
+# For example, set the com.xyz.foo logger to only log SEVERE messages:
+# com.xyz.foo.level = SEVERE
+
+org.jbpm.level=FINEST
+org.jbpm.pvm.internal.tx.level=FINE
+org.jbpm.pvm.internal.wire.level=FINE
+org.jbpm.pvm.internal.util.level=FINE
+
+org.hibernate.level=FINEST
+org.hibernate.cfg.HbmBinder.level=SEVERE
+org.hibernate.cfg.SettingsFactory.level=SEVERE
+# org.hibernate.SQL.level=FINEST
+# org.hibernate.type.level=FINEST
+# org.hibernate.tool.hbm2ddl.SchemaExport.level=FINEST
+# org.hibernate.transaction.level=FINEST

Modified: jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/AssignFileTypeDeployer.java
===================================================================
--- jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/AssignFileTypeDeployer.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/AssignFileTypeDeployer.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -21,20 +21,22 @@
  */
 package org.jbpm.pvm.internal.deploy;
 
+import java.io.Serializable;
 import java.util.HashMap;
 import java.util.Map;
 
 import org.jbpm.pvm.internal.svc.DeploymentImpl;
 
-
 /**
  * @author Tom Baeyens
  */
-public class AssignFileTypeDeployer implements Deployer {
+public class AssignFileTypeDeployer implements Deployer, Serializable {
   
   /* maps extensions to file types */
   Map<String, String> fileTypes = new HashMap<String, String>();
 
+  private static final long serialVersionUID = 1L;
+
   public void deploy(DeploymentImpl deployment) {
     for (String fileName: deployment.getFileNames()) {
       for (String extension: fileTypes.keySet()) {

Modified: jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/CheckProblemsDeployer.java
===================================================================
--- jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/CheckProblemsDeployer.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/CheckProblemsDeployer.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -21,6 +21,8 @@
  */
 package org.jbpm.pvm.internal.deploy;
 
+import java.io.Serializable;
+
 import org.jbpm.JbpmException;
 import org.jbpm.Problem;
 import org.jbpm.log.Log;
@@ -30,9 +32,10 @@
 /**
  * @author Tom Baeyens
  */
-public class CheckProblemsDeployer implements Deployer {
+public class CheckProblemsDeployer implements Deployer, Serializable {
   
   private static final Log log = Log.getLog(CheckProblemsDeployer.class.getName());
+  private static final long serialVersionUID = 1L;
 
   public void deploy(DeploymentImpl deployment) {
     if (deployment.hasProblems()) {

Modified: jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/CheckProcessDeployer.java
===================================================================
--- jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/CheckProcessDeployer.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/CheckProcessDeployer.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -21,7 +21,7 @@
  */
 package org.jbpm.pvm.internal.deploy;
 
-import java.util.List;
+import java.io.Serializable;
 
 import org.jbpm.ProcessDefinition;
 import org.jbpm.client.ClientProcessDefinition;
@@ -35,8 +35,9 @@
 /**
  * @author Tom Baeyens
  */
-public class CheckProcessDeployer implements Deployer {
+public class CheckProcessDeployer implements Deployer, Serializable {
  
+  private static final long serialVersionUID = 1L;
   private static final Log log = Log.getLog(CheckProcessDeployer.class.getName());
   
   protected boolean assignVersion = true;
@@ -74,9 +75,6 @@
     checkKey(processSourceName, processDefinition, deployment, pvmDbSession);
     checkVersion(processSourceName, processDefinition, deployment, pvmDbSession);
     checkId(processSourceName, processDefinition, deployment, pvmDbSession);
-    
-    String key = processDefinition.getKey();
-
   }
 
   protected void checkKey(String processSourceName, ProcessDefinitionImpl processDefinition, DeploymentImpl deployment, PvmDbSession pvmDbSession) {

Modified: jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/SaveDeployer.java
===================================================================
--- jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/SaveDeployer.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/deploy/SaveDeployer.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -21,19 +21,20 @@
  */
 package org.jbpm.pvm.internal.deploy;
 
-import org.jbpm.JbpmException;
+import java.io.Serializable;
+
 import org.jbpm.ProcessDefinition;
 import org.jbpm.env.Environment;
 import org.jbpm.log.Log;
 import org.jbpm.pvm.internal.svc.DeploymentImpl;
 import org.jbpm.session.PvmDbSession;
 
-
 /**
  * @author Tom Baeyens
  */
-public class SaveDeployer implements Deployer {
+public class SaveDeployer implements Deployer, Serializable {
 
+  private static final long serialVersionUID = 1L;
   private static Log log = Log.getLog(SaveDeployer.class.getName());
 
   public void deploy(DeploymentImpl deployment) {

Modified: jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/wire/xml/WireParser.java
===================================================================
--- jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/wire/xml/WireParser.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/pvm/src/main/java/org/jbpm/pvm/internal/wire/xml/WireParser.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -128,6 +128,7 @@
     "jbpm.pvm.wire.bindings.xml",
     "jbpm.jpdl.wire.bindings.xml",
     "jbpm.task.wire.bindings.xml",
+    "jbpm.enterprise.wire.bindings.xml",
     "jbpm.user.wire.bindings.xml"
   }; 
 

Modified: jbpm4/trunk/pom.xml
===================================================================
--- jbpm4/trunk/pom.xml	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/pom.xml	2009-01-09 06:18:25 UTC (rev 3623)
@@ -1,42 +1,38 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<!-- ====================================================================== -->
-<!--                                                                        -->
-<!--  JBoss, the OpenSource J2EE webOS                                      -->
-<!--                                                                        -->
-<!--  Distributable under LGPL license.                                     -->
-<!--  See terms of license at http://www.gnu.org.                           -->
-<!--                                                                        -->
-<!-- ====================================================================== -->
+  <!-- ====================================================================== -->
+  <!--                                                                        -->
+  <!--  JBoss, the OpenSource J2EE webOS                                      -->
+  <!--                                                                        -->
+  <!--  Distributable under LGPL license.                                     -->
+  <!--  See terms of license at http://www.gnu.org.                           -->
+  <!--                                                                        -->
+  <!-- ====================================================================== -->
 
-<!-- $Id$ -->
+  <!-- $Id$ -->
 
-<project xmlns="http://maven.apache.org/POM/4.0.0" 
-         xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-         xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
-         
+<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+  xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
+
   <modelVersion>4.0.0</modelVersion>
 
   <name>jBPM 4</name>
   <groupId>org.jbpm.jbpm4</groupId>
   <artifactId>jbpm</artifactId>
   <packaging>pom</packaging>
-  
+
   <version>4.0.0-SNAPSHOT</version>
-  
+
   <organization>
     <name>JBoss, a division of Red Hat</name>
     <url>http://www.jboss.org</url>
   </organization>
-  
-  
+
   <!-- Modules -->
   <modules>
     <module>modules/api</module>
     <module>modules/examples</module>
-    <!-- 
     <module>modules/enterprise</module>
-    -->
     <module>modules/jpdl</module>
     <module>modules/log</module>
     <module>modules/pvm</module>
@@ -45,26 +41,24 @@
     <module>modules/test-db</module>
     <module>modules/test-pojo</module>
   </modules>
-  
+
   <!-- Properties -->
   <properties>
+    <cactus.version>1.8.0</cactus.version>
     <hibernate.version>3.2.6.ga</hibernate.version>
     <hsqldb.version>1.8.0.7</hsqldb.version>
-    <jboss.j2ee.version>4.2.1.GA</jboss.j2ee.version>
+    <jboss.j2ee.version>4.2.2.GA</jboss.j2ee.version>
     <jbossesb.version>4.4.0.GA</jbossesb.version>
+    <jboss.client.version>4.2.2.GA</jboss.client.version>
     <jsr233.version>2.0.3</jsr233.version>
     <juel.version>2.1.0</juel.version>
+    <junit.version>3.8.1</junit.version>
     <log4j.version>1.2.14</log4j.version>
-    <spring.version>2.5.4</spring.version>
     <servlet-api.version>2.5</servlet-api.version>
-    <cactus.version>13-1.7.1</cactus.version>
-    <junit.version>3.8.1</junit.version>
+    <spring.version>2.5.4</spring.version>
     <stax.api.version>1.0.1</stax.api.version>
-    <!-- 
-    <cactus.version>13-1.7.1</cactus.version>
-     -->
   </properties>
-  
+
   <!-- DependencyManagement -->
   <dependencyManagement>
     <dependencies>
@@ -89,13 +83,18 @@
         <version>${version}</version>
       </dependency>
 
-      <!-- Please sort by groupid -->      
+      <!-- Please sort by groupid -->
       <dependency>
-        <groupId>log4j</groupId>
-        <artifactId>log4j</artifactId>
-        <version>${log4j.version}</version>
+        <groupId>org.apache.cactus</groupId>
+        <artifactId>cactus.core.framework.wrapper.javaEE.14</artifactId>
+        <version>${cactus.version}</version>
       </dependency>
       <dependency>
+        <groupId>org.apache.cactus</groupId>
+        <artifactId>cactus.integration.shared.api</artifactId>
+        <version>${cactus.version}</version>
+      </dependency>
+      <dependency>
         <groupId>org.hibernate</groupId>
         <artifactId>hibernate</artifactId>
         <version>${hibernate.version}</version>
@@ -121,6 +120,11 @@
         <version>${jbossesb.version}</version>
       </dependency>
       <dependency>
+        <groupId>org.jboss.client</groupId>
+        <artifactId>jbossall-client</artifactId>
+        <version>${jboss.client.version}</version>
+      </dependency>
+      <dependency>
         <groupId>juel</groupId>
         <artifactId>juel</artifactId>
         <version>${juel.version}</version>
@@ -146,6 +150,11 @@
         <version>${jsr233.version}</version>
       </dependency>
       <dependency>
+        <groupId>log4j</groupId>
+        <artifactId>log4j</artifactId>
+        <version>${log4j.version}</version>
+      </dependency>
+      <dependency>
         <groupId>org.springframework</groupId>
         <artifactId>spring</artifactId>
         <version>${spring.version}</version>
@@ -155,13 +164,7 @@
         <artifactId>servlet-api</artifactId>
         <version>${servlet-api.version}</version>
       </dependency>
-      <dependency>
-        <groupId>cactus</groupId>
-        <artifactId>cactus</artifactId>
-        <version>${cactus.version}</version>
-      </dependency>
     </dependencies>
-    
   </dependencyManagement>
 
   <scm>
@@ -169,13 +172,13 @@
     <developerConnection>scm:svn:https://svn.jboss.org/repos/jbpm/jbpm4</developerConnection>
     <url>http://fisheye.jboss.com/browse/JbpmSvn/jbpm4</url>
   </scm>
-  
+
   <!-- IssueManagement -->
   <issueManagement>
     <system>jira</system>
     <url>http://jira.jboss.org/jira/browse/JBPM</url>
   </issueManagement>
-  
+
   <!-- Licenses -->
   <licenses>
     <license>
@@ -183,7 +186,7 @@
       <url>http://repository.jboss.com/licenses/lgpl.txt</url>
     </license>
   </licenses>
-  
+
   <!-- Plugins -->
   <build>
     <plugins>
@@ -232,7 +235,7 @@
         </configuration>
       </plugin>
     </plugins>
-    
+
     <!-- PluginManagement -->
     <pluginManagement>
       <plugins>
@@ -246,11 +249,9 @@
           <artifactId>maven-assembly-plugin</artifactId>
           <version>2.2-beta-2</version>
         </plugin>
-        <!-- 
-        <plugin>
-          <groupId>org.apache.maven.plugins</groupId>
-          <artifactId>maven-dependency-plugin</artifactId>
-        </plugin>
+        <!--
+          <plugin> <groupId>org.apache.maven.plugins</groupId>
+          <artifactId>maven-dependency-plugin</artifactId> </plugin>
         -->
         <plugin>
           <groupId>org.codehaus.mojo</groupId>
@@ -275,8 +276,8 @@
       </plugins>
     </pluginManagement>
   </build>
-  
-  <!-- Profiles -->  
+
+  <!-- Profiles -->
   <profiles>
     <profile>
       <id>distro</id>
@@ -336,7 +337,7 @@
       </dependencies>
       <build>
         <plugins>
-        
+
           <plugin>
             <artifactId>maven-dependency-plugin</artifactId>
             <executions>
@@ -366,17 +367,17 @@
                 </goals>
                 <configuration>
                   <outputDirectory>target/resolved.properties</outputDirectory>
-                  <resources>          
+                  <resources>
                     <resource>
                       <directory>target/jbpm-db/db.properties</directory>
                       <filtering>true</filtering>
                     </resource>
-                  </resources>              
-                </configuration>            
+                  </resources>
+                </configuration>
               </execution>
             </executions>
           </plugin>
-          
+
           <plugin>
             <artifactId>maven-antrun-plugin</artifactId>
             <executions>
@@ -389,9 +390,9 @@
                 <configuration>
                   <tasks>
                     <mkdir dir="target/test-classes" />
-                    <copy file="target/resolved.properties/${database}.properties" 
-                          tofile="target/test-classes/hibernate.properties" 
-                          overwrite="true"/>
+                    <copy file="target/resolved.properties/${database}.properties"
+                      tofile="target/test-classes/hibernate.properties"
+                      overwrite="true" />
                   </tasks>
                 </configuration>
               </execution>
@@ -404,25 +405,21 @@
                 <configuration>
                   <tasks>
                     <property file="target/test-classes/hibernate.properties" />
-                    <sql src="target/jbpm-db/drop/jbpm.${database}.drop.sql" 
-                         driver="${hibernate.connection.driver_class}"
-                         url="${hibernate.connection.url}"
-                         userid="${hibernate.connection.username}"
-                         password="${hibernate.connection.password}"
-                         onerror="continue">
-                       <classpath>
-                         <path refid="maven.test.classpath" />
-                       </classpath>
+                    <sql src="target/jbpm-db/drop/jbpm.${database}.drop.sql"
+                      driver="${hibernate.connection.driver_class}" url="${hibernate.connection.url}"
+                      userid="${hibernate.connection.username}" password="${hibernate.connection.password}"
+                      onerror="continue">
+                      <classpath>
+                        <path refid="maven.test.classpath" />
+                      </classpath>
                     </sql>
-                    <sql src="target/jbpm-db/create/jbpm.${database}.create.sql" 
-                         driver="${hibernate.connection.driver_class}"
-                         url="${hibernate.connection.url}"
-                         userid="${hibernate.connection.username}"
-                         password="${hibernate.connection.password}"
-                         onerror="continue">
-                       <classpath>
-                         <path refid="maven.test.classpath" />
-                       </classpath>
+                    <sql src="target/jbpm-db/create/jbpm.${database}.create.sql"
+                      driver="${hibernate.connection.driver_class}" url="${hibernate.connection.url}"
+                      userid="${hibernate.connection.username}" password="${hibernate.connection.password}"
+                      onerror="continue">
+                      <classpath>
+                        <path refid="maven.test.classpath" />
+                      </classpath>
                     </sql>
                   </tasks>
                 </configuration>
@@ -436,14 +433,12 @@
                 <configuration>
                   <tasks>
                     <property file="target/test-classes/hibernate.properties" />
-                    <sql src="target/jbpm-db/drop/jbpm.${database}.drop.sql" 
-                         driver="${hibernate.connection.driver_class}"
-                         url="${hibernate.connection.url}"
-                         userid="${hibernate.connection.username}"
-                         password="${hibernate.connection.password}">
-                       <classpath>
-                         <path refid="maven.test.classpath" />
-                       </classpath>
+                    <sql src="target/jbpm-db/drop/jbpm.${database}.drop.sql"
+                      driver="${hibernate.connection.driver_class}" url="${hibernate.connection.url}"
+                      userid="${hibernate.connection.username}" password="${hibernate.connection.password}">
+                      <classpath>
+                        <path refid="maven.test.classpath" />
+                      </classpath>
                     </sql>
                   </tasks>
                 </configuration>
@@ -544,10 +539,8 @@
         </repository>
       </repositories>
     </profile>
-
   </profiles>
-  
-  
+
   <!-- Repositories -->
   <repositories>
     <repository>
@@ -586,7 +579,7 @@
       <url>http://gwt-maven.googlecode.com/svn/trunk/mavenrepo/</url>
     </repository>
   </repositories>
-  
+
   <!-- PluginRepositories -->
   <pluginRepositories>
     <pluginRepository>
@@ -613,7 +606,7 @@
       <url>http://gwt-maven.googlecode.com/svn/trunk/mavenrepo/</url>
     </pluginRepository>
   </pluginRepositories>
-  
+
   <!-- DistributionManagement -->
   <distributionManagement>
     <repository>
@@ -627,5 +620,5 @@
       <url>dav:https://snapshots.jboss.org/maven2</url>
     </snapshotRepository>
   </distributionManagement>
-  
+
 </project>




More information about the jbpm-commits mailing list
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/CommandExecutorTest.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/CommandExecutorTest.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -29,8 +29,8 @@
 
 import org.apache.cactus.ServletTestCase;
 
-import org.jbpm.enterprise.internal.custom.InsertPhraseCmd;
-import org.jbpm.enterprise.internal.custom.RemovePhraseCmd;
+import org.jbpm.enterprise.internal.custom.InsertCommentCmd;
+import org.jbpm.enterprise.internal.custom.RemoveCommentCmd;
 import org.jbpm.enterprise.internal.ejb.CommandExecutorSLSB;
 import org.jbpm.enterprise.internal.ejb.LocalCommandExecutor;
 import org.jbpm.enterprise.internal.ejb.LocalCommandExecutorHome;
@@ -80,43 +80,43 @@
    * <h3>Preconditions</h3>
    * The TEST_PHRASE table does not contain any row with the specified text.
    * <h3>Behavior</h3>
    * The {@link InsertPhraseCmd} command creates a row with the specified text.
    * <h3>Postconditions</h3>
    * A new row with the specified text exists in the table. The
    * {@link RemovePhraseCmd} command removes the row, and the return value confirms
    * it was there.
    */
   public void testHappyCommand() throws CreateException {
     String text = "been there, done that";
-    commandExecutor.execute(new InsertPhraseCmd(text));
+    commandExecutor.execute(new InsertCommentCmd(text));
     // verify phrase was inserted
-    assertTrue(commandExecutor.execute(new RemovePhraseCmd(text)));
+    assertTrue(commandExecutor.execute(new RemoveCommentCmd(text)));
   }
 
   /**
    * This scenario tests a command that throws a checked exception inside the
-   * {@link InsertPhraseCmd#execute(org.jbpm.env.Environment) execute} method.
+   * {@link InsertCommentCmd#execute(org.jbpm.env.Environment) execute} method.
    * <h3>Preconditions</h3>
    * The TEST_PHRASE table does not contain any row with the specified text.
    * <h3>Behavior</h3>
    * The {@link InsertPhraseCmd} command creates a row with the specified text. The
    * command is configured to throw a checked exception before completing.
    * <h3>Postconditions</h3>
    * The command executor throws an {@link EJBException} and rolls back the
    * managed transaction. No row with the specified text exists in the database.
    * The {@link RemovePhraseCmd} command return value confirms the row was not
    * there.
    */
   public void testNoisyCommand() throws CreateException {
     String text = "houston, we have a problem";
     // insert phrase via command
     try {
-      commandExecutor.execute(new InsertPhraseCmd(text, /* fail? */true));
+      commandExecutor.execute(new InsertCommentCmd(text, /* fail? */true));
       fail("expected: " + EJBException.class.getSimpleName());
     } catch (EJBException e) {
       log.info("noisy command threw exception", e);
       // verify phrase was NOT inserted
-      assertFalse(commandExecutor.execute(new RemovePhraseCmd(text)));
+      assertFalse(commandExecutor.execute(new RemoveCommentCmd(text)));
     }
   }
 }
@@ -80,43 +80,43 @@
    * The TEST_PHRASE table does not contain any row with the specified text.
    * <h3>Behavior</h3>
-   * The {@link InsertPhraseCmd} command creates a row with the specified text.
+   * The {@link InsertCommentCmd} command creates a row with the specified text.
    * <h3>Postconditions</h3>
    * A new row with the specified text exists in the table. The
@@ -80,43 +80,43 @@
    * <h3>Postconditions</h3>
    * A new row with the specified text exists in the table. The
-   * {@link RemovePhraseCmd} command removes the row, and the return value confirms
+   * {@link RemoveCommentCmd} command removes the row, and the return value confirms
    * it was there.
    */
@@ -80,43 +80,43 @@
    * The TEST_PHRASE table does not contain any row with the specified text.
    * <h3>Behavior</h3>
-   * The {@link InsertPhraseCmd} command creates a row with the specified text. The
+   * The {@link InsertCommentCmd} command creates a row with the specified text. The
    * command is configured to throw a checked exception before completing.
    * <h3>Postconditions</h3>
@@ -80,43 +80,43 @@
    * The command executor throws an {@link EJBException} and rolls back the
    * managed transaction. No row with the specified text exists in the database.
-   * The {@link RemovePhraseCmd} command return value confirms the row was not
+   * The {@link RemoveCommentCmd} command return value confirms the row was not
    * there.
    */

Modified: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/CommandReceiverTest.java
===================================================================
--- jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/CommandReceiverTest.java	2009-01-09 01:33:08 UTC (rev 3622)
+++ jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/CommandReceiverTest.java	2009-01-09 06:18:25 UTC (rev 3623)
@@ -38,8 +38,8 @@
 import org.apache.cactus.ServletTestCase;
 
 import org.jbpm.cmd.Command;
-import org.jbpm.enterprise.internal.custom.InsertPhraseCmd;
-import org.jbpm.enterprise.internal.custom.RemovePhraseCmd;
+import org.jbpm.enterprise.internal.custom.InsertCommentCmd;
+import org.jbpm.enterprise.internal.custom.RemoveCommentCmd;
 import org.jbpm.enterprise.internal.ejb.CommandReceiverMDB;
 import org.jbpm.test.enterprise.IntegrationTestSetup;
 
@@ -58,7 +58,8 @@
   private static Destination commandQueue;
 
   public static Test suite() {
-    return new IntegrationTestSetup(CommandReceiverTest.class, "jbpm-enterprise-test.ear");
+    return new IntegrationTestSetup(CommandReceiverTest.class,
+        "jbpm-enterprise-test.ear");
   }
 
   @Override
@@ -67,9 +68,12 @@
       // retrieve managed objects
       Context initial = new InitialContext();
       try {
-        jmsConnectionFactory = (ConnectionFactory) initial.lookup("java:comp/env/jms/CommandConnectionFactory");
-        commandQueue = (Destination) initial.lookup("java:comp/env/jms/CommandQueue");
-      } finally {
+        jmsConnectionFactory = (ConnectionFactory) initial
+            .lookup("java:comp/env/jms/CommandConnectionFactory");
+        commandQueue = (Destination) initial
+            .lookup("java:comp/env/jms/CommandQueue");
+      }
+      finally {
         initial.close();
       }
     }
@@ -87,24 +91,22 @@
   }
 
   /**
    * This scenario tests a command message that completes with no incident.
    * <h3>Preconditions</h3>
    * The TEST_PHRASE table does not contain any row with the specified text.
    * <h3>Behavior</h3>
    * The {@link InsertPhraseCmd} command message creates a row with the specified
    * text. Once the command completes, the command receiver sends the result to
    * the reply queue.
    * <h3>Postconditions</h3>
    * A new row with the specified text exists in the table. The
    * {@link RemovePhraseCmd} command message removes the row. The result sent to
    * the reply queue confirms the row was there.
    */
   public void testHappyMessage() throws JMSException {
     final String text = "been there, done that";
-    Session jmsSession = jmsConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+    Session jmsSession = jmsConnection.createSession(false,
+        Session.AUTO_ACKNOWLEDGE);
     try {
       // send insert command
-      Command<Void> insertCommand = new InsertPhraseCmd(text, /* fail? */false);
+      Command<Void> insertCommand = new InsertCommentCmd(text, /* fail? */false);
       Message insertMessage = jmsSession.createObjectMessage(insertCommand);
       Destination replyTo = jmsSession.createTemporaryQueue();
       insertMessage.setJMSReplyTo(replyTo);
@@ -112,50 +114,52 @@
       producer.send(insertMessage);
 
       // receive insertion response
-      MessageConsumer insertConsumer = jmsSession.createConsumer(replyTo, "JMSCorrelationID = '" + insertMessage.getJMSMessageID() + "'");
-      ObjectMessage responseMessage = (ObjectMessage) insertConsumer.receive(TIMEOUT);
+      MessageConsumer insertConsumer = jmsSession.createConsumer(replyTo,
+          "JMSCorrelationID = '" + insertMessage.getJMSMessageID() + "'");
+      ObjectMessage responseMessage = (ObjectMessage) insertConsumer
+          .receive(TIMEOUT);
       assertNull(responseMessage.getObject());
 
       // send remove command
-      Command<Boolean> removeCommand = new RemovePhraseCmd(text);
+      Command<Boolean> removeCommand = new RemoveCommentCmd(text);
       Message removeMessage = jmsSession.createObjectMessage(removeCommand);
       removeMessage.setJMSReplyTo(replyTo);
       producer.send(removeMessage);
 
       // receive removal response
-      MessageConsumer removeConsumer = jmsSession.createConsumer(replyTo, "JMSCorrelationID = '" + removeMessage.getJMSMessageID() + "'");
+      MessageConsumer removeConsumer = jmsSession.createConsumer(replyTo,
+          "JMSCorrelationID = '" + removeMessage.getJMSMessageID() + "'");
       responseMessage = (ObjectMessage) removeConsumer.receive(TIMEOUT);
       // verify phrase was inserted
       assertTrue((Boolean) responseMessage.getObject());
-    } finally {
+    }
+    finally {
       jmsSession.close();
     }
   }
 
   /**
    * This scenario tests a command message that throws a checked exception
    * inside the {@link InsertPhraseCmd#execute(org.jbpm.env.Environment) execute}
    * method.
    * <h3>Preconditions</h3>
    * The TEST_PHRASE table does not contain any row with the specified text.
    * <h3>Behavior</h3>
    * The {@link InsertPhraseCmd} command message creates a row with the specified
    * text. The command is configured to throw a checked exception before
    * completing. The exception prevents the command receiver from sending the
    * result to the reply queue.
    * <h3>Postconditions</h3>
    * The command receiver rolls back the managed transaction and puts the
    * insertion message back in the command queue. No row with the specified
    * exists in the database. The {@link RemovePhraseCmd} command result sent to the
    * reply queue confirms the row was not there.
    */
   public void testNoisyMessage() throws JMSException {
     final String text = "houston, we have a problem";
     // insert phrase via command
-    Session jmsSession = jmsConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+    Session jmsSession = jmsConnection.createSession(false,
+        Session.AUTO_ACKNOWLEDGE);
     try {
       // send insert command
-      Command<Void> insertCommand = new InsertPhraseCmd(text, /* fail? */true);
+      Command<Void> insertCommand = new InsertCommentCmd(text, /* fail? */true);
       Message insertMessage = jmsSession.createObjectMessage(insertCommand);
       Destination replyTo = jmsSession.createTemporaryQueue();
       insertMessage.setJMSReplyTo(replyTo);
@@ -163,22 +167,27 @@
       producer.send(insertMessage);
 
       // receive insertion response
-      MessageConsumer insertConsumer = jmsSession.createConsumer(replyTo, "JMSCorrelationID = '" + insertMessage.getJMSMessageID() + "'");
-      ObjectMessage insertResponse = (ObjectMessage) insertConsumer.receive(TIMEOUT);
+      MessageConsumer insertConsumer = jmsSession.createConsumer(replyTo,
+          "JMSCorrelationID = '" + insertMessage.getJMSMessageID() + "'");
+      ObjectMessage insertResponse = (ObjectMessage) insertConsumer
+          .receive(TIMEOUT);
       assertNull(insertResponse);
 
       // send remove command
-      Command<Boolean> removeCommand = new RemovePhraseCmd(text);
+      Command<Boolean> removeCommand = new RemoveCommentCmd(text);
       Message removeMessage = jmsSession.createObjectMessage(removeCommand);
       removeMessage.setJMSReplyTo(replyTo);
       producer.send(removeMessage);
 
       // receive removal response
-      MessageConsumer removeConsumer = jmsSession.createConsumer(replyTo, "JMSCorrelationID = '" + removeMessage.getJMSMessageID() + "'");
-      ObjectMessage removeResponse = (ObjectMessage) removeConsumer.receive(TIMEOUT);
+      MessageConsumer removeConsumer = jmsSession.createConsumer(replyTo,
+          "JMSCorrelationID = '" + removeMessage.getJMSMessageID() + "'");
+      ObjectMessage removeResponse = (ObjectMessage) removeConsumer
+          .receive(TIMEOUT);
       // verify phrase was NOT inserted
       assertFalse((Boolean) removeResponse.getObject());
-    } finally {
+    }
+    finally {
       jmsSession.close();
     }
   }
@@ -87,24 +91,22 @@
 
   /**
-   * This scenario tests a command message that completes with no incident.
-   * <h3>Preconditions</h3>
-   * The TEST_PHRASE table does not contain any row with the specified text.
-   * <h3>Behavior</h3>
-   * The {@link InsertPhraseCmd} command message creates a row with the specified
-   * text. Once the command completes, the command receiver sends the result to
-   * the reply queue.
-   * <h3>Postconditions</h3>
-   * A new row with the specified text exists in the table. The
-   * {@link RemovePhraseCmd} command message removes the row. The result sent to
-   * the reply queue confirms the row was there.
+   * This scenario tests a command message that completes with no incident. <h3>
+   * Preconditions</h3> The TEST_PHRASE table does not contain any row with the
+   * specified text. <h3>Behavior</h3> The {@link InsertCommentCmd} command
+   * message creates a row with the specified text. Once the command completes,
+   * the command receiver sends the result to the reply queue. <h3>
+   * Postconditions</h3> A new row with the specified text exists in the table.
+   * The {@link RemoveCommentCmd} command message removes the row. The result
+   * sent to the reply queue confirms the row was there.
    */
   public void testHappyMessage() throws JMSException {
@@ -112,50 +114,52 @@
   /**
    * This scenario tests a command message that throws a checked exception
-   * inside the {@link InsertPhraseCmd#execute(org.jbpm.env.Environment) execute}
-   * method.
-   * <h3>Preconditions</h3>
-   * The TEST_PHRASE table does not contain any row with the specified text.
-   * <h3>Behavior</h3>
-   * The {@link InsertPhraseCmd} command message creates a row with the specified
+   * inside the {@link InsertCommentCmd#execute(org.jbpm.env.Environment)
+   * execute} method. <h3>Preconditions</h3> The TEST_PHRASE table does not
+   * contain any row with the specified text. <h3>Behavior</h3> The
+   * {@link InsertCommentCmd} command message creates a row with the specified
    * text. The command is configured to throw a checked exception before
    * completing. The exception prevents the command receiver from sending the
@@ -112,50 +114,52 @@
    * text. The command is configured to throw a checked exception before
    * completing. The exception prevents the command receiver from sending the
-   * result to the reply queue.
-   * <h3>Postconditions</h3>
-   * The command receiver rolls back the managed transaction and puts the
-   * insertion message back in the command queue. No row with the specified
-   * exists in the database. The {@link RemovePhraseCmd} command result sent to the
-   * reply queue confirms the row was not there.
+   * result to the reply queue. <h3>Postconditions</h3> The command receiver
+   * rolls back the managed transaction and puts the insertion message back in
+   * the command queue. No row with the specified exists in the database. The
+   * {@link RemoveCommentCmd} command result sent to the reply queue confirms
+   * the row was not there.
    */
   public void testNoisyMessage() throws JMSException {

Modified: jbpm4/trunk/modules/enterprise/src/test/java/org/jbpm/enterprise/internal/ejb/EjbTimerSessionTest.java
===================================================================